@@ -12,7 +12,7 @@ def main(req: func.HttpRequest) -> func.HttpResponse:
     o = Onefuzz()
     o.config(
         endpoint=os.environ.get("ONEFUZZ_ENDPOINT"),
-        authority=os.environ.get("ONEFUZZ_AUTHORITY"),
+        override_authority=os.environ.get("ONEFUZZ_AUTHORITY"),
         client_id=os.environ.get("ONEFUZZ_CLIENT_ID"),
     )
     info = o.info.get()
