@@ -53,6 +53,7 @@ class AFL(Command):
         notification_config: Optional[NotificationConfig] = None,
         debug: Optional[List[TaskDebugFlag]] = None,
         ensemble_sync_delay: Optional[int] = None,
+        extra_container: Optional[Container] = None,
     ) -> Optional[Job]:
         """
         Basic AFL job
@@ -93,6 +94,7 @@ class AFL(Command):
             ContainerType.reports,
             ContainerType.unique_reports,
         )
+
         if existing_inputs:
             self.onefuzz.containers.get(existing_inputs)
             helper.containers[ContainerType.inputs] = existing_inputs
@@ -133,6 +135,11 @@ class AFL(Command):
             (ContainerType.inputs, helper.containers[ContainerType.inputs]),
         ]
 
+        if extra_container is not None:
+            containers.append(
+                (ContainerType.extra, helper.containers[ContainerType.extra])
+            )
+
         self.logger.info("creating afl fuzz task")
         fuzzer_task = self.onefuzz.tasks.create(
             helper.job.job_id,
@@ -166,6 +173,11 @@ class AFL(Command):
             ),
         ]
 
+        if extra_container is not None:
+            report_containers.append(
+                (ContainerType.extra, helper.containers[ContainerType.extra])
+            )
+
         self.logger.info("creating generic_crash_report task")
         self.onefuzz.tasks.create(
             helper.job.job_id,
