@@ -50,6 +50,7 @@ class Radamsa(Command):
         debug: Optional[List[TaskDebugFlag]] = None,
         ensemble_sync_delay: Optional[int] = None,
         target_timeout: Optional[int] = None,
+        extra_container: Optional[Container] = None,
     ) -> Optional[Job]:
         """
         Basic radamsa job
@@ -90,6 +91,7 @@ class Radamsa(Command):
             ContainerType.no_repro,
             ContainerType.analysis,
         )
+
         if existing_inputs:
             self.onefuzz.containers.get(existing_inputs)
             helper.containers[ContainerType.readonly_inputs] = existing_inputs
@@ -155,6 +157,9 @@ class Radamsa(Command):
             ),
         ]
 
+        if extra_container is not None:
+            containers.append((ContainerType.extra, extra_container))
+
         fuzzer_task = self.onefuzz.tasks.create(
             helper.job.job_id,
             TaskType.generic_generator,
@@ -188,6 +193,9 @@ class Radamsa(Command):
             (ContainerType.no_repro, helper.containers[ContainerType.no_repro]),
         ]
 
+        if extra_container is not None:
+            report_containers.append((ContainerType.extra, extra_container))
+
         self.logger.info("creating generic_crash_report task")
         self.onefuzz.tasks.create(
             helper.job.job_id,
@@ -231,6 +239,9 @@ class Radamsa(Command):
                 (ContainerType.crashes, helper.containers[ContainerType.crashes]),
             ]
 
+            if extra_container is not None:
+                analysis_containers.append((ContainerType.extra, extra_container))
+
             self.onefuzz.tasks.create(
                 helper.job.job_id,
                 TaskType.generic_analysis,
