@@ -56,6 +56,7 @@ class Regression(Command):
         check_fuzzer_help: bool = True,
         delete_input_container: bool = True,
         check_regressions: bool = False,
+        extra_container: Optional[Container] = None,
     ) -> None:
         """
         generic regression task
@@ -89,6 +90,7 @@ class Regression(Command):
             check_fuzzer_help=check_fuzzer_help,
             delete_input_container=delete_input_container,
             check_regressions=check_regressions,
+            extra_container=extra_container,
         )
 
     def libfuzzer(
@@ -115,8 +117,8 @@ class Regression(Command):
         check_fuzzer_help: bool = True,
         delete_input_container: bool = True,
         check_regressions: bool = False,
+        extra_container: Optional[Container] = None,
     ) -> None:
-
         """
         libfuzzer regression task
 
@@ -149,6 +151,7 @@ class Regression(Command):
             check_fuzzer_help=check_fuzzer_help,
             delete_input_container=delete_input_container,
             check_regressions=check_regressions,
+            extra_container=extra_container,
         )
 
     def _create_job(
@@ -176,8 +179,8 @@ class Regression(Command):
         check_fuzzer_help: bool = True,
         delete_input_container: bool = True,
         check_regressions: bool = False,
+        extra_container: Optional[Container] = None,
     ) -> None:
-
         if dryrun:
             return None
 
@@ -218,6 +221,9 @@ class Regression(Command):
             ),
         ]
 
+        if extra_container:
+            containers.append((ContainerType.extra, extra_container))
+
         if crashes:
             helper.containers[
                 ContainerType.readonly_inputs
